@@ -1,24 +1,51 @@
-from django.conf import settings
-from django import forms
-from django.template.defaultfilters import slugify
-from django.utils.translation import ugettext as _, ugettext_lazy
-from django.forms.util import ErrorList
-from django.contrib.auth.forms import UserCreationForm
-from django.contrib.auth.models import User, Permission, Group
-from django.contrib.contenttypes.models import ContentType
-from django.db.models.fields import BooleanField
-
-
-from cms.models import Page, Title, PagePermission, PageUser, ACCESS_PAGE,\
+# -*- coding: utf-8 -*-
+from cms.apphook_pool import apphook_pool
+from cms.forms.widgets import UserSelectAdminWidget
+from cms.models import Page, PagePermission, PageUser, ACCESS_PAGE, \
     PageUserGroup
-from cms.utils.urlutils import any_path_re
-from cms.utils.permissions import get_current_user, get_subordinate_users,\
-    get_subordinate_groups, mail_page_user_change
-from cms.admin.widgets import UserSelectAdminWidget
 from cms.utils.page import is_valid_page_slug
-from django.forms.widgets import HiddenInput
+from cms.utils.permissions import get_current_user, get_subordinate_users, \
+    get_subordinate_groups, mail_page_user_change
+from cms.utils.urlutils import any_path_re
+from django import forms
+from django.conf import settings
+from django.contrib.auth.forms import UserCreationForm
+from django.contrib.auth.models import Permission, User
+from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site
 from django.core.exceptions import ValidationError
+from django.db.models.fields import BooleanField
+from django.forms.util import ErrorList
+from django.forms.widgets import HiddenInput
+from django.template.defaultfilters import slugify
+from django.utils.translation import ugettext_lazy as _, get_language
+from menus.menu_pool import menu_pool
+
+def get_permission_acessor(obj):
+    if isinstance(obj, (PageUser, User,)):
+        rel_name = 'user_permissions' 
+    else:
+        rel_name = 'permissions'
+    return getattr(obj, rel_name)
+
+def save_permissions(data, obj):
+    models = ((Page, 'page'), (PageUser, 'pageuser'), (PageUserGroup, 'pageuser'), (PagePermission, 'pagepermission'))
+    
+    if not obj.pk:
+        # save obj, otherwise we can't assign permissions to him
+        obj.save()
+    permission_acessor = get_permission_acessor(obj)
+    
+    for model, name in models:
+        content_type = ContentType.objects.get_for_model(model)
+        for t in ('add', 'change', 'delete'):
+            # add permission `t` to model `model`
+            codename = getattr(model._meta, 'get_%s_permission' % t)()
+            permission = Permission.objects.get(content_type=content_type, codename=codename)
+            if data.get('can_%s_%s' % (t, name), None):
+                permission_acessor.add(permission)
+            else:
+                permission_acessor.remove(permission)
 
 
 class PageAddForm(forms.ModelForm):
@@ -31,7 +58,7 @@ class PageAddForm(forms.ModelForm):
     
     class Meta:
         model = Page
-        exclude = ["created_by", "changed_by"]
+        exclude = ["created_by", "changed_by", "placeholders"]
     
     def __init__(self, *args, **kwargs):
         super(PageAddForm, self).__init__(*args, **kwargs)
@@ -39,6 +66,17 @@ class PageAddForm(forms.ModelForm):
         self.fields['site'].widget = HiddenInput()
         if not self.fields['site'].initial:
             self.fields['site'].initial = Site.objects.get_current().pk
+        site_id = self.fields['site'].initial
+        languages = []
+        language_mappings = dict(settings.LANGUAGES)
+        if site_id in settings.CMS_SITE_LANGUAGES:
+            for lang in settings.CMS_SITE_LANGUAGES[site_id]:
+                languages.append((lang, language_mappings.get(lang, lang)))
+        else:
+            languages = settings.CMS_LANGUAGES
+        self.fields['language'].choices = languages
+        if not self.fields['language'].initial:
+            self.fields['language'].initial = get_language()
         if self.fields['parent'].initial and \
             settings.CMS_TEMPLATE_INHERITANCE_MAGIC in \
             [name for name, value in settings.CMS_TEMPLATES]:
@@ -51,14 +89,25 @@ class PageAddForm(forms.ModelForm):
             slug = cleaned_data['slug']
         else:
             slug = ""
+        
         page = self.instance
-        lang = cleaned_data['language']
+        lang = cleaned_data.get('language', None)
+        # No language, can not go further, but validation failed already
+        if not lang: 
+            return cleaned_data
+        
         if 'parent' not in cleaned_data:
             cleaned_data['parent'] = None
         parent = cleaned_data.get('parent', None)
-        site = self.cleaned_data.get('site', Site.objects.get_current())
-        if not is_valid_page_slug(page, parent, lang, slug, site):
-            self._errors['slug'] = ErrorList([ugettext_lazy('Another page with this slug already exists')])
+        
+        try:
+            site = self.cleaned_data.get('site', Site.objects.get_current())
+        except Site.DoesNotExist:
+            site = None
+            raise ValidationError("No site found for current settings.")
+        
+        if site and not is_valid_page_slug(page, parent, lang, slug, site):
+            self._errors['slug'] = ErrorList([_('Another page with this slug already exists')])
             del cleaned_data['slug']
         return cleaned_data
     
@@ -76,14 +125,12 @@ class PageAddForm(forms.ModelForm):
         
     
 class PageForm(PageAddForm):
-    APPLICATION_URLS = (('', '----------'), ) + settings.CMS_APPLICATIONS_URLS
-    
     menu_title = forms.CharField(label=_("Menu Title"), widget=forms.TextInput(),
         help_text=_('Overwrite what is displayed in the menu'), required=False)
     page_title = forms.CharField(label=_("Page Title"), widget=forms.TextInput(),
         help_text=_('Overwrites what is displayed at the top of your browser or in bookmarks'), required=False)
     application_urls = forms.ChoiceField(label=_('Application'), 
-        choices=APPLICATION_URLS, required=False,  
+        choices=(), required=False,  
         help_text=_('Hook application to this page.'))
     overwrite_url = forms.CharField(label=_('Overwrite URL'), max_length=255, required=False,
         help_text=_('Keep this field empty if standard path should be used.'))
@@ -97,22 +144,31 @@ class PageForm(PageAddForm):
     meta_description = forms.CharField(label='Description meta tag', required=False, widget=forms.Textarea,
         help_text=_('A description of the page sometimes used by search engines.'))
     meta_keywords = forms.CharField(label='Keywords meta tag', max_length=255, required=False,
-        help_text=_('A list of comma seperated keywords sometimes used by search engines.'))    
-        
+        help_text=_('A list of comma seperated keywords sometimes used by search engines.'))
+    
+    def __init__(self, *args, **kwargs):
+        super(PageForm, self).__init__(*args, **kwargs)
+        if 'navigation_extenders' in self.fields:
+            self.fields['navigation_extenders'].widget = forms.Select({}, [('', "---------")] + menu_pool.get_menus_by_attribute("cms_enabled", True))
+        if 'application_urls' in self.fields:
+            self.fields['application_urls'].choices = [('', "---------")] + apphook_pool.get_apphooks()
+    
     def clean(self):
         cleaned_data = super(PageForm, self).clean()
-        id = cleaned_data['reverse_id']
-        site_id = cleaned_data['site']
-        if id:
-            if Page.objects.filter(reverse_id=id, site=site_id, publisher_is_draft=True).exclude(pk=self.instance.pk).count():
-                raise forms.ValidationError(ugettext_lazy('A page with this reverse URL id exists already.'))
+        if 'reverse_id' in self.fields:
+            id = cleaned_data['reverse_id']
+            site_id = cleaned_data['site']
+            if id:
+                if Page.objects.filter(reverse_id=id, site=site_id, publisher_is_draft=True).exclude(pk=self.instance.pk).count():
+                    raise forms.ValidationError(_('A page with this reverse URL id exists already.'))
         return cleaned_data
 
     def clean_overwrite_url(self):
-        url = self.cleaned_data['overwrite_url']
-        if url:
-            if not any_path_re.match(url):
-                raise forms.ValidationError(ugettext_lazy('Invalid URL, use /my/url format.'))
+        if 'overwrite_url' in self.fields:
+            url = self.cleaned_data['overwrite_url']
+            if url:
+                if not any_path_re.match(url):
+                    raise forms.ValidationError(_('Invalid URL, use /my/url format.'))
         return url
     
 
@@ -156,10 +212,10 @@ class PagePermissionInlineAdminForm(forms.ModelForm):
             # this is a missconfiguration - user can add/move page to current
             # page but after he does this, he will not have permissions to 
             # access this page anymore, so avoid this
-            raise forms.ValidationError(ugettext_lazy('Add page permission requires also access to children, or descendants, otherwise added page can\'t be changed by its creator.'))
+            raise forms.ValidationError(_('Add page permission requires also access to children, or descendants, otherwise added page can\'t be changed by its creator.'))
         
         if can_add and not can_edit:
-            raise forms.ValidationError(ugettext_lazy('Add page permission also requires edit page permission.'))
+            raise forms.ValidationError(_('Add page permission also requires edit page permission.'))
         # TODO: finish this, but is it really required? might be nice to have 
         
         # check if permissions assigned in cms are correct, and display an message
@@ -186,7 +242,7 @@ class GlobalPagePermissionAdminForm(forms.ModelForm):
     def clean(self):
         super(GlobalPagePermissionAdminForm, self).clean()
         if not self.cleaned_data['user'] and not self.cleaned_data['group']:
-            raise forms.ValidationError(ugettext_lazy('Please select user or group first.'))
+            raise forms.ValidationError(_('Please select user or group first.'))
         return self.cleaned_data
 
 
@@ -221,7 +277,7 @@ class GenericCmsPermissionForm(forms.ModelForm):
                 initials['can_%s_%s' % (t, name)] = obj.has_perm('%s.%s' % (model._meta.app_label, codename)) 
         return initials
         """
-        permission_acessor = self.permission_acessor(obj)
+        permission_acessor = get_permission_acessor(obj)
         for model in models:
             name = model.__name__.lower()
             content_type = ContentType.objects.get_for_model(model)
@@ -231,31 +287,8 @@ class GenericCmsPermissionForm(forms.ModelForm):
                 initials['can_%s_%s' % (t, name)] = codename in permissions 
         return initials
     
-    def permission_acessor(self, obj):
-        if isinstance(obj, PageUser):
-            rel_name = 'user_permissions' 
-        else:
-            rel_name = 'permissions'
-        return getattr(obj, rel_name)
-
     def save_permissions(self, obj):
-        models = ((Page, 'page'), (PageUser, 'pageuser'), (PageUserGroup, 'pageuser'), (PagePermission, 'pagepermission'))
-        
-        if not obj.pk:
-            # save obj, otherwise we can't assign permissions to him
-            obj.save()
-        permission_acessor = self.permission_acessor(obj)
-        
-        for model, name in models:
-            content_type = ContentType.objects.get_for_model(model)
-            for t in ('add', 'change', 'delete'):
-                # add permission `t` to model `model`
-                codename = getattr(model._meta, 'get_%s_permission' % t)()
-                permission = Permission.objects.get(content_type=content_type, codename=codename)
-                if self.cleaned_data.get('can_%s_%s' % (t, name), None):
-                    permission_acessor.add(permission)
-                else:
-                    permission_acessor.remove(permission)
+        save_permissions(self.cleaned_data, obj)
         
 
 class PageUserForm(UserCreationForm, GenericCmsPermissionForm):
@@ -302,7 +335,6 @@ class PageUserForm(UserCreationForm, GenericCmsPermissionForm):
         notify_user = self.cleaned_data['notify_user']
         if notify_user and not self.cleaned_data.get('email', None):
             raise forms.ValidationError(_("Email notification requires valid email address."))
-        
         if self.cleaned_data['can_add_page'] and not self.cleaned_data['can_change_page']:
             raise forms.ValidationError(_("The permission to add new pages requires the permission to change pages!"))
         if self.cleaned_data['can_add_pageuser'] and not self.cleaned_data['can_change_pageuser']:
@@ -322,12 +354,12 @@ class PageUserForm(UserCreationForm, GenericCmsPermissionForm):
         created = not bool(user.pk)
         # assign creator to user
         if created:
+            get_current_user()
             user.created_by = get_current_user()
-
         if commit:
             user.save()
 
-        self.save_permissions(user)
+        save_permissions(self.cleaned_data, user)
 
         if self.cleaned_data['notify_user']:
             mail_page_user_change(user, created, self.cleaned_data['password1'])
