@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from django.conf import settings
 from cms.admin.forms import GlobalPagePermissionAdminForm, \
     PagePermissionInlineAdminForm
@@ -22,6 +23,7 @@ class PagePermissionInlineAdmin(admin.TabularInline):
     form = PagePermissionInlineAdminForm
     # use special formset, so we can use queryset defined here
     formset = BaseInlineFormSetWithQuerySet
+    classes = ['collapse', 'collapsed'] 
     
     def __init__(self, *args, **kwargs):
         super(PagePermissionInlineAdmin, self).__init__(*args, **kwargs)
@@ -83,7 +85,7 @@ class GlobalPagePermissionAdmin(admin.ModelAdmin):
     
     form = GlobalPagePermissionAdminForm
     
-    search_fields = ('user__username', 'user__firstname', 'user__lastname', 'group__name')
+    search_fields = ('user__username', 'user__first_name', 'user__last_name', 'group__name')
     
     exclude = []
     
@@ -122,9 +124,6 @@ class GenericCmsPermissionAdmin(object):
                 fn = getattr(opts, 'get_%s_permission' % t)
                 if request.user.has_perm(opts.app_label + '.' + fn()):
                     fields.append('can_%s_%s' % (t, name))
-            if model == Page:
-                fields.append('can_recover_page')
-        
             if fields:
                 fieldsets.insert(2 + i, (title, {'fields': (fields,)}))
             i += 1
