@@ -1,13 +1,14 @@
+# -*- coding: utf-8 -*-
 from django.conf import settings
 from django.db import models
 from django.contrib.sites.models import Site
 from django.db.models import Q
 from cms.exceptions import NoPermissionsException
-from cms.cache.permissions import get_permission_cache, set_permission_cache
 from publisher import PublisherManager
 from cms.models.query import PageQuerySet
 from cms.utils.i18n import get_fallback_languages
 
+
 try:
     set
 except NameError:
@@ -96,6 +97,7 @@ class PageManager(PublisherManager):
         
         Plugins can define a 'search_fields' tuple similar to ModelAdmin classes
         """
+        from cms.plugin_pool import plugin_pool
         qs = self.get_query_set()
         if settings.CMS_MODERATOR:
             qs = qs.public()
@@ -108,14 +110,13 @@ class PageManager(PublisherManager):
         
         # find 'searchable' plugins and build query
         qp = Q()
-        # cannot import CMSPlugin due to Manager -> Page -> Plugin circle!
-        CMSPlugin = models.get_model('cms','cmsplugin')
-        for c in CMSPlugin.__subclasses__():
+        plugins = plugin_pool.get_all_plugins()
+        for plugin in plugins:
+            c = plugin.model
             if hasattr(c, 'search_fields'):
                 for field in c.search_fields:
-                    qp |= Q(**{'cmsplugin__%s__%s__icontains' % \
+                    qp |= Q(**{'placeholders__cmsplugin__%s__%s__icontains' % \
                                    (c.__name__.lower(), field):q})
-        
         if language:
             qt &= Q(title_set__language=language)
             qp &= Q(cmsplugin__language=language)
@@ -166,41 +167,52 @@ class TitleManager(PublisherManager):
             return None
         else:
             return titles
+            
+    # created new public method to meet test case requirement and to get a list of titles for published pages
+    def public(self):
+        return self.get_query_set().filter(page__publisher_is_draft=False, page__published=True)
         
-    def set_or_create(self, page, language, slug=None, title=None, application_urls=None,
-        overwrite_url=None, redirect=None, meta_description=None, meta_keywords=None, page_title=None, menu_title=None):
+    def drafts(self):
+        return self.get_query_set().filter(page__publisher_is_draft=True)
+        
+    def set_or_create(self, request, page, form, language):
         """
         set or create a title for a particular page and language
         """
+        base_fields = [
+            'slug',
+            'title',
+            'application_urls',
+            'redirect',
+            'meta_description',
+            'meta_keywords',
+            'page_title',
+            'menu_title'
+        ]
+        cleaned_data = form.cleaned_data
         try:
             obj = self.get(page=page, language=language)
-            if title != None:
-                obj.title = title
-            if slug != None:
-                obj.slug = slug
-            if application_urls != None:
-                obj.application_urls = application_urls
-            if redirect != None:
-                obj.redirect = redirect
-            if meta_description != None:
-                obj.meta_description = meta_description
-            if meta_keywords != None:
-                obj.meta_keywords = meta_keywords            
-            if page_title != None:
-                obj.page_title = page_title
-            if menu_title != None:
-                obj.menu_title = menu_title                            
         except self.model.DoesNotExist:
-            obj = self.model(
-                page=page, language=language, title=title, slug=slug,
-                application_urls=application_urls, redirect=redirect,
-                meta_description=meta_description, meta_keywords=meta_keywords,
-                page_title=page_title, menu_title=menu_title)
-        if overwrite_url:
-            obj.has_url_overwrite = True
+            data = {}
+            for name in base_fields:
+                if name in cleaned_data:
+                    data[name] = cleaned_data[name]
+            data['page'] = page
+            data['language'] = language
+            if page.has_advanced_settings_permission(request):
+                overwrite_url = cleaned_data.get('overwrite_url', None)
+                if overwrite_url:
+                    data['has_url_overwrite'] = True
+                    data['path'] = overwrite_url
+            return self.create(**data)
+        
+        for name in base_fields:
+            value = cleaned_data.get(name, None)
+            setattr(obj, name, value)
+        if page.has_advanced_settings_permission(request):
+            overwrite_url = cleaned_data.get('overwrite_url', None)
+            obj.has_url_overwrite = bool(overwrite_url)
             obj.path = overwrite_url
-        else:
-            obj.has_url_overwrite = False
         obj.save()
         return obj
 
@@ -430,8 +442,6 @@ class PagePermissionsPermissionManager(models.Manager):
         # read from cache if posssible
         #cached = get_permission_cache(user, attr)
         #if cached is not None:
-        #    print "retunr cache"
-        #    print cached
         #    return cached
         
         from cms.models import GlobalPagePermission, PagePermission, MASK_PAGE,\
@@ -451,6 +461,7 @@ class PagePermissionsPermissionManager(models.Manager):
         for permission in qs:
             is_allowed = getattr(permission, attr)
             if is_allowed:
+
                 # can add is special - we are actually adding page under current page
                 if permission.grant_on & MASK_PAGE or attr is "can_add":
                     page_id_allow_list.append(permission.page.id)
@@ -458,7 +469,6 @@ class PagePermissionsPermissionManager(models.Manager):
                     page_id_allow_list.extend(permission.page.get_children().values_list('id', flat=True))
                 elif permission.grant_on & MASK_DESCENDANTS:
                     page_id_allow_list.extend(permission.page.get_descendants().values_list('id', flat=True))
-        # store value in cache
         #set_permission_cache(user, attr, page_id_allow_list)
         return page_id_allow_list
 
