@@ -13,6 +13,7 @@ from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core.cache import cache
 from django.core.mail import mail_managers
+from django.utils.html import escape
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 from itertools import chain
@@ -284,7 +285,7 @@ class PageAttribute(Tag):
             return ''
         if page and name in self.valid_attributes:
             f = getattr(page, "get_%s" % name)
-            return f(language=lang, fallback=True)
+            return escape(f(language=lang, fallback=True))
         return ''
 register.tag(PageAttribute)
 
@@ -428,4 +429,4 @@ class PluginsMedia(Tag):
 
     def __repr__(self):
         return "<PluginsMediaNode Node: %s>" % getattr(self, 'name', '')
-register.tag(PluginsMedia)
\ No newline at end of file
+register.tag(PluginsMedia)
