@@ -22,8 +22,15 @@ def cut_after(node, levels, removed):
         removed.extend(node.children)
         node.children = []
     else:
+        removed_local = []
         for n in node.children:
-            cut_after(n, levels - 1, removed)
+            if n.visible:
+                cut_after(n, levels - 1, removed)
+            else:
+                removed_local.append(n)
+        for n in removed_local:
+            node.children.remove(n)
+        removed.extend(removed_local)
 
 def remove(node, removed):
     removed.append(node)
