@@ -1,8 +1,8 @@
+# -*- coding: utf-8 -*-
 from django.conf import settings
-from models import Publisher, MpttPublisher
 from mptt_support import Mptt
 from manager import PublisherManager
 
-__all__ = ('Publisher', 'PublisherManager', 'MpttPublisher', 'Mptt', 'VERSION')
+__all__ = ('PublisherManager', 'Mptt', 'VERSION')
 
 VERSION = (0, 4, 'sintab')
\ No newline at end of file
